@@ -1,6 +1,3 @@
-import os
-
-on_windows = os.name == 'nt'
 DEFAULT_TURNS = 200
 
 # The order of imports matters!
@@ -23,5 +20,5 @@ from .match_generator import *
 from .tournament import Tournament
 from .result_set import ResultSet, ResultSetFromFile
 from .ecosystem import Ecosystem
-from .fingerprint import AshlockFingerprint
+from .fingerprint import AshlockFingerprint, TransitiveFingerprint
 
