@@ -1,4 +1,3 @@
-import warnings
 from distutils.version import LooseVersion
 
 from .result_set import ResultSet
@@ -7,20 +6,9 @@ import tqdm
 
 from typing import List, Union
 
-matplotlib_installed = True
-try:
-    import matplotlib
-    import matplotlib.pyplot as plt
-    import matplotlib.transforms as transforms
-    from mpl_toolkits.axes_grid1 import make_axes_locatable
-except ImportError:  # pragma: no cover
-    matplotlib_installed = False
-except RuntimeError:  # pragma: no cover
-    matplotlib_installed = False
-    warnings.warn(
-        'Matplotlib failed to import and so no plots will be produced. This '
-        'could be caused by using a virtual environment on OSX. See '
-        'http://matplotlib.org/faq/virtualenv_faq.html for details.')
+import matplotlib
+import matplotlib.pyplot as plt
+import matplotlib.transforms as transforms
 
 titleType = List[str]
 namesType = List[str]
@@ -37,7 +25,6 @@ def default_cmap(version: str = "2.0") -> str:
 class Plot(object):
     def __init__(self, result_set: ResultSet) -> None:
         self.result_set = result_set
-        self.matplotlib_installed = matplotlib_installed
         self.nplayers = self.result_set.nplayers
         self.players = self.result_set.players
 
@@ -46,8 +33,6 @@ class Plot(object):
         ax: matplotlib.axes.SubplotBase = None
     ) -> matplotlib.figure.Figure:
         """For making violinplots."""
-        if not self.matplotlib_installed:  # pragma: no cover
-            return None
 
         if ax is None:
             _, ax = plt.subplots()
@@ -112,8 +97,6 @@ class Plot(object):
         self, title: titleType = None, ax: matplotlib.axes.SubplotBase = None
     ) -> matplotlib.figure.Figure:
         """Plots the distributions for the number of wins for each strategy."""
-        if not self.matplotlib_installed:  # pragma: no cover
-            return None
 
         data, names = self._winplot_dataset
         figure = self._violinplot(data, names, title=title, ax=ax)
@@ -129,7 +112,8 @@ class Plot(object):
     @property
     def _sdv_plot_dataset(self):
         ordering = self._sd_ordering
-        diffs = self.result_set.score_diffs
+        diffs = [[score_diff for opponent in player for score_diff in opponent]
+                 for player in self.result_set.score_diffs]
         # Reorder and grab names
         diffs = [diffs[i] for i in ordering]
         ranked_names = [str(self.players[i]) for i in ordering]
@@ -184,8 +168,6 @@ class Plot(object):
         ax: matplotlib.axes.SubplotBase = None
     ) -> matplotlib.figure.Figure:
         """Generic heatmap plot"""
-        if not self.matplotlib_installed:  # pragma: no cover
-            return None
 
         if ax is None:
             _, ax = plt.subplots()
@@ -233,8 +215,6 @@ class Plot(object):
         self, eco, title: titleType = None, logscale: bool = True,
         ax: matplotlib.axes.SubplotBase =None
     ) -> matplotlib.figure.Figure:
-        if not self.matplotlib_installed:  # pragma: no cover
-            return None
 
         populations = eco.population_sizes
 
