@@ -1,34 +1,33 @@
 import random
 import numpy
-from axelrod.actions import Action, Actions
+from axelrod.action import Action
 
 
 def random_choice(p: float = 0.5) -> Action:
     """
-    Return 'C' with probability `p`, else return 'D'
+    Return C with probability `p`, else return D
 
     No random sample is carried out if p is 0 or 1.
 
     Parameters
     ----------
-
     p : float
-        The probability of picking 'C'
+        The probability of picking C
 
     Returns
     -------
-    axelrod.Actions.C or axelrod.Actions.D
+    axelrod.Action
     """
     if p == 0:
-        return Actions.D
+        return Action.D
 
     if p == 1:
-        return Actions.C
+        return Action.C
 
     r = random.random()
     if r < p:
-        return Actions.C
-    return Actions.D
+        return Action.C
+    return Action.D
 
 
 def randrange(a: int, b: int) -> int:
@@ -58,5 +57,5 @@ class Pdf(object):
         """Sample from the pdf"""
         index = numpy.random.choice(a=range(self.size), p=self.probability)
         # Numpy cannot sample from a list of n dimensional objects for n > 1,
-        # need to sample an index
+        # need to sample an index.
         return self.sample_space[index]
