@@ -24,6 +24,8 @@ class Davis(Player):
     A player starts by cooperating for 10 rounds then plays Grudger,
     defecting if at any point the opponent has defected.
 
+    This strategy came 8th in Axelrod's original tournament.
+
     Names:
 
     - Davis: [Axelrod1980]_
@@ -61,9 +63,18 @@ class Davis(Player):
 
 
 class RevisedDowning(Player):
-    """Revised Downing attempts to determine if players are cooperative or not.
-    If so, it cooperates with them. This strategy would have won Axelrod's first
-    tournament.
+    """This strategy attempts to estimate the next move of the opponent by estimating
+    the probability of cooperating given that they defected (:math:`p(C|D)`) or
+    cooperated on the previous round (:math:`p(C|C)`). These probabilities are
+    continuously updated during play and the strategy attempts to maximise the long
+    term play. Note that the initial values are :math:`p(C|C)=p(C|D)=.5`.
+
+    Downing is implemented as `RevisedDowning`. Apparently in the first tournament
+    the strategy was implemented incorrectly and defected on the first two rounds.
+    This can be controlled by setting `revised=True` to prevent the initial defections.
+
+    This strategy came 10th in Axelrod's original tournament but would have won
+    if it had been implemented correctly.
 
     Names:
 
@@ -89,8 +100,8 @@ class RevisedDowning(Player):
         self.bad = 0.0
         self.nice1 = 0
         self.nice2 = 0
-        self.total_C = 0 # note the same as self.cooperations
-        self.total_D = 0 # note the same as self.defections
+        self.total_C = 0  # note the same as self.cooperations
+        self.total_D = 0  # note the same as self.defections
 
     def strategy(self, opponent: Player) -> Action:
         round_number = len(self.history) + 1
@@ -129,22 +140,16 @@ class RevisedDowning(Player):
             move = D
         return move
 
-    def reset(self):
-        super().reset()
-        self.good = 1.0
-        self.bad = 0.0
-        self.nice1 = 0
-        self.nice2 = 0
-        self.total_C = 0 # not the same as self.cooperations
-        self.total_D = 0 # not the same as self.defections
-
 
 class Feld(Player):
     """
     Submitted to Axelrod's first tournament by Scott Feld.
 
-    Defects when opponent defects. Cooperates with a probability that decreases
-    to 0.5 at round 200.
+    This strategy plays Tit For Tat, always defecting if the opponent defects but
+    cooperating when the opponent cooperates with a gradually decreasing probability
+    until it is only .5.
+
+    This strategy came 11th in Axelrod's original tournament.
 
     Names:
 
@@ -153,7 +158,7 @@ class Feld(Player):
 
     name = "Feld"
     classifier = {
-        'memory_depth': 200, # Varies actually, eventually becomes depth 1
+        'memory_depth': 200,  # Varies actually, eventually becomes depth 1
         'stochastic': True,
         'makes_use_of': set(),
         'long_run_time': False,
@@ -203,9 +208,12 @@ class Grofman(Player):
     """
     Submitted to Axelrod's first tournament by Bernard Grofman.
 
-    Cooperate on the first 2 moves. Return opponent's move for the next 5.
-    Then cooperate if the last round's moves were the same, otherwise cooperate
-    with probability 2/7.
+    Cooperate on the first two rounds and
+    returns the opponent's last action for the next 5. For the rest of the game
+    Grofman cooperates if both players selected the same action in the previous
+    round, and otherwise cooperates randomly with probability 2/7.
+
+    This strategy came 4th in Axelrod's original tournament.
 
     Names:
 
@@ -234,7 +242,6 @@ class Grofman(Player):
         return random_choice(2 / 7)
 
 
-
 class Joss(MemoryOnePlayer):
     """
     Submitted to Axelrod's first tournament by Johann Joss.
@@ -242,6 +249,8 @@ class Joss(MemoryOnePlayer):
     Cooperates with probability 0.9 when the opponent cooperates, otherwise
     emulates Tit-For-Tat.
 
+    This strategy came 12th in Axelrod's original tournament.
+
     Names:
 
     - Joss: [Axelrod1980]_
@@ -273,17 +282,28 @@ class Nydegger(Player):
     third move, its choice is determined from the 3 preceding outcomes in the
     following manner.
 
-    Let A be the sum formed by counting the other's defection as 2 points and
-    one's own as 1 point, and giving weights of 16, 4, and 1 to the preceding
-    three moves in chronological order. The choice can be described as defecting
-    only when A equals
-    1, 6, 7, 17, 22, 23, 26, 29, 30, 31, 33, 38, 39, 45, 49, 54, 55, 58, or 61.
+    .. math::
+
+        A = 16 a_1 + 4 a_2 + a_3
+
+    Where :math:`a_i` is dependent on the outcome of the previous :math:`i` th
+    round.  If both strategies defect, :math:`a_i=3`, if the opponent only defects:
+    :math:`a_i=2` and finally if it is only this strategy that defects then
+    :math:`a_i=1`.
+
+    Finally this strategy defects if and only if:
+
+    .. math::
+
+        A \in \{1, 6, 7, 17, 22, 23, 26, 29, 30, 31, 33, 38, 39, 45, 49, 54, 55, 58, 61\}
 
     Thus if all three preceding moves are mutual defection, A = 63 and the rule
     cooperates. This rule was designed for use in laboratory experiments as a
     stooge which had a memory and appeared to be trustworthy, potentially
     cooperative, but not gullible.
 
+    This strategy came 3rd in Axelrod's original tournament.
+
     Names:
 
     - Nydegger: [Axelrod1980]_
@@ -311,7 +331,7 @@ class Nydegger(Player):
 
     @staticmethod
     def score_history(my_history: List[Action], opponent_history: List[Action],
-        score_map: Dict[Tuple[Action, Action], int]) -> int:
+                      score_map: Dict[Tuple[Action, Action], int]) -> int:
 
         """Implements the Nydegger formula A = 16 a_1 + 4 a_2 + a_3"""
         a = 0
@@ -346,6 +366,8 @@ class Shubik(Player):
     Plays like Tit-For-Tat with the following modification. After each
     retaliation, the number of rounds that Shubik retaliates increases by 1.
 
+    This strategy came 5th in Axelrod's original tournament.
+
     Names:
 
     - Shubik: [Axelrod1980]_
@@ -399,12 +421,6 @@ class Shubik(Player):
             return D
         return C
 
-    def reset(self):
-        super().reset()
-        self.is_retaliating = False
-        self.retaliation_length = 0
-        self.retaliation_remaining = 0
-
 
 class Tullock(Player):
     """
@@ -413,6 +429,8 @@ class Tullock(Player):
     Cooperates for the first 11 rounds then randomly cooperates 10% less often
     than the opponent has in previous rounds.
 
+    This strategy came 13th in Axelrod's original tournament.
+
     Names:
 
     - Tullock: [Axelrod1980]_
@@ -494,14 +512,15 @@ class UnnamedStrategy(Player):
 
 @FinalTransformer((D, D), name_prefix=None)
 class SteinAndRapoport(Player):
-    """
-    A player who plays according to statistic methods.
-    Begins by playing C for the first four (4) rounds, then it plays
-    tit for tat and at the last 2 round it Defects. Every 15 turns it
-    runs a chi-squared test to check whether the opponent behaves randomly
-    or not. In case the opponent behaves randomly then Stein and Rapoport
-    Defects until the next 15 round (where we check again), otherwise it
-    still plays TitForTat.0
+    """This strategy plays a modification of Tit For Tat.
+
+    1. It cooperates for the first 4 moves.
+    2. It defects on the last 2 moves.
+    3. Every 15 moves it makes use of a `chi-squared
+       test <http://en.wikipedia.org/wiki/Chi-squared_test>`_ to check if the
+       opponent is playing randomly.
+
+    This strategy came 6th in Axelrod's original tournament.
 
     Names:
 
@@ -552,6 +571,125 @@ class SteinAndRapoport(Player):
         else:  # TitForTat if opponent plays not randomly
             return opponent.history[-1]
 
-    def reset(self):
-        super().reset()
-        self.opponent_is_random = False
+
+class TidemanAndChieruzzi(Player):
+    """
+    This strategy begins by playing Tit For Tat and then follows the following
+    rules:
+
+    1. Every run of defections played by the opponent increases the number of
+    defections that this strategy retaliates with by 1.
+
+    2. The opponent is given a ‘fresh start’ if:
+        - it is 10 points behind this strategy
+        - and it has not just started a run of defections
+        - and it has been at least 20 rounds since the last ‘fresh start’
+        - and there are more than 10 rounds remaining in the match
+        - and the total number of defections differs from a 50-50 random sample
+          by at least 3.0 standard deviations.
+
+    A ‘fresh start’ is a sequence of two cooperations followed by an assumption
+    that the game has just started (everything is forgotten).
+
+    This strategy came 2nd in Axelrod’s original tournament.
+
+    Names:
+
+    - TidemanAndChieruzzi: [Axelrod1980]_
+    """
+
+    name = 'Tideman and Chieruzzi'
+    classifier = {
+        'memory_depth': float('inf'),
+        'stochastic': False,
+        'makes_use_of': {"game", "length"},
+        'long_run_time': False,
+        'inspects_source': False,
+        'manipulates_source': False,
+        'manipulates_state': False
+    }
+
+    def __init__(self) -> None:
+        super().__init__()
+        self.is_retaliating = False
+        self.retaliation_length = 0
+        self.retaliation_remaining = 0
+        self.current_score = 0
+        self.opponent_score = 0
+        self.last_fresh_start = 0
+        self.fresh_start = False
+
+    def _decrease_retaliation_counter(self):
+        """Lower the remaining owed retaliation count and flip to non-retaliate
+        if the count drops to zero."""
+        if self.is_retaliating:
+            self.retaliation_remaining -= 1
+            if self.retaliation_remaining == 0:
+                self.is_retaliating = False
+
+    def _fresh_start(self):
+        """Give the opponent a fresh start by forgetting the past"""
+        self.is_retaliating = False
+        self.retaliation_length = 0
+        self.retaliation_remaining = 0
+
+    def _score_last_round(self, opponent: Player):
+        """Updates the scores for each player."""
+        # Load the default game if not supplied by a tournament.
+        game = self.match_attributes["game"]
+        last_round = (self.history[-1], opponent.history[-1])
+        scores = game.score(last_round)
+        self.current_score += scores[0]
+        self.opponent_score += scores[1]
+
+    def strategy(self, opponent: Player) -> Action:
+        if not opponent.history:
+            return C
+
+        # Calculate the scores.
+        self._score_last_round(opponent)
+
+        # Check if we have recently given the strategy a fresh start.
+        if self.fresh_start:
+            self.fresh_start = False
+            return C  # Second cooperation
+
+        # Check conditions to give opponent a fresh start.
+        current_round = len(self.history) + 1
+        if self.last_fresh_start == 0:
+            valid_fresh_start = True
+        # There needs to be at least 20 rounds before the next fresh start
+        else:
+            valid_fresh_start = current_round - self.last_fresh_start >= 20
+
+        if valid_fresh_start:
+            valid_points = self.current_score - self.opponent_score >= 10
+            valid_rounds = self.match_attributes['length'] - current_round >= 10
+            opponent_is_cooperating = opponent.history[-1] == C
+            if valid_points and valid_rounds and opponent_is_cooperating:
+                # 50-50 split is based off the binomial distribution.
+                N = opponent.cooperations + opponent.defections
+                # std_dev = sqrt(N*p*(1-p)) where p is 1 / 2.
+                std_deviation = (N ** (1 / 2)) / 2
+                lower = N / 2 - 3 * std_deviation
+                upper = N / 2 + 3 * std_deviation
+                if self.defections <= lower or self.defections >= upper:
+                    # Opponent deserves a fresh start
+                    self.last_fresh_start = current_round
+                    self._fresh_start()
+                    self.fresh_start = True
+                    return C  # First cooperation
+
+        if self.is_retaliating:
+            # Are we retaliating still?
+            self._decrease_retaliation_counter()
+            return D
+
+        if opponent.history[-1] == D:
+            self.is_retaliating = True
+            self.retaliation_length += 1
+            self.retaliation_remaining = self.retaliation_length
+            self._decrease_retaliation_counter()
+            return D
+
+        return C
