@@ -12,6 +12,9 @@ class TitForTat(Player):
     A player starts by cooperating and then mimics the previous action of the
     opponent.
 
+    This strategy was referred to as the *'simplest'* strategy submitted to
+    Axelrod's first tournament. It came first.
+
     Note that the code for this strategy is written in a fairly verbose
     way. This is done so that it can serve as an example strategy for
     those who might be new to Python.
@@ -52,6 +55,7 @@ class TitFor2Tats(Player):
     Names:
 
     - Tit for two Tats: [Axelrod1984]_
+    - Slow tit for two tats: Original name by Ranjini Das
     """
 
     name = "Tit For 2 Tats"
@@ -342,7 +346,7 @@ class OmegaTFT(Player):
             return opponent.history[-1]
 
         # Are we deadlocked? (in a CD -> DC loop)
-        if (self.deadlock_counter >= self.deadlock_threshold):
+        if self.deadlock_counter >= self.deadlock_threshold:
             move = C
             if self.deadlock_counter == self.deadlock_threshold:
                 self.deadlock_counter = self.deadlock_threshold + 1
@@ -373,10 +377,6 @@ class OmegaTFT(Player):
                     self.deadlock_counter = 0
         return move
 
-    def reset(self):
-        super().reset()
-        self.randomness_counter = 0
-        self.deadlock_counter = 0
 
 
 class Gradual(Player):
@@ -433,13 +433,6 @@ class Gradual(Player):
 
         return C
 
-    def reset(self):
-        super().reset()
-        self.calming = False
-        self.punishing = False
-        self.punishment_count = 0
-        self.punishment_limit = 0
-
 
 @TrackHistoryTransformer(name_prefix=None)
 class ContriteTitForTat(Player):
@@ -487,46 +480,6 @@ class ContriteTitForTat(Player):
 
         return opponent.history[-1]
 
-    def reset(self):
-        super().reset()
-        self.contrite = False
-        self._recorded_history = []
-
-
-class SlowTitForTwoTats(Player):
-    """
-    A player plays C twice, then if the opponent plays the same move twice,
-    plays that move.
-
-    Names:
-
-    - Slow tit for two tats: Original name by Ranjini Das
-    """
-
-    name = 'Slow Tit For Two Tats'
-    classifier = {
-        'memory_depth': 2,
-        'stochastic': False,
-        'makes_use_of': set(),
-        'long_run_time': False,
-        'inspects_source': False,
-        'manipulates_source': False,
-        'manipulates_state': False
-    }
-
-    def strategy(self, opponent: Player) -> Action:
-
-        # Start with two cooperations
-        if len(self.history) < 2:
-            return C
-
-        # Mimic if opponent plays the same move twice
-        if opponent.history[-2] == opponent.history[-1]:
-            return opponent.history[-1]
-
-        # Otherwise cooperate
-        return C
-
 
 class AdaptiveTitForTat(Player):
     """ATFT - Adaptive Tit For Tat (Basic Model)
@@ -575,7 +528,8 @@ class AdaptiveTitForTat(Player):
 
     def __init__(self, rate: float = 0.5) -> None:
         super().__init__()
-        self.rate, self.starting_rate = rate, rate
+        self.rate = rate
+        self.world = rate
 
     def strategy(self, opponent: Player) -> Action:
 
@@ -592,12 +546,6 @@ class AdaptiveTitForTat(Player):
 
         return D
 
-    def reset(self):
-
-        super().reset()
-        self.world = 0.5
-        self.rate = self.starting_rate
-
 
 class SpitefulTitForTat(Player):
     """
@@ -641,10 +589,6 @@ class SpitefulTitForTat(Player):
                 return D
             return C
 
-    def reset(self):
-        super().reset()
-        self.retaliating = False
-
 
 class SlowTitForTwoTats2(Player):
     """
@@ -680,6 +624,7 @@ class SlowTitForTwoTats2(Player):
         # Otherwise play previous move
         return self.history[-1]
 
+
 @FinalTransformer((D,), name_prefix=None)
 class Alexei(Player):
     """
@@ -708,6 +653,7 @@ class Alexei(Player):
             return D
         return C
 
+
 @FinalTransformer((D,), name_prefix=None)
 class EugineNier(Player):
     """
@@ -744,6 +690,103 @@ class EugineNier(Player):
             return D
         return opponent.history[-1]
 
-    def reset(self):
-        super().reset()
+
+class NTitsForMTats(Player):
+    """
+    A parameterizable Tit-for-Tat,
+    The arguments are:
+    1) M: the number of defection before retaliation
+    2) N: the number of retaliations
+
+    Names:
+
+    - N Tit(s) For M Tat(s): Original name by Marc Harper
+    """
+
+    name = 'N Tit(s) For M Tat(s)'
+    classifier = {
+        'memory_depth': float('inf'),
+        'stochastic': False,
+        'makes_use_of': set(),
+        'long_run_time': False,
+        'inspects_source': False,
+        'manipulates_source': False,
+        'manipulates_state': False
+    }
+
+    def __init__(self, N: int=3, M: int=2) -> None:
+        """
+        Parameters
+        ----------
+        N: int
+            Number of retaliations
+        M: int
+            Number of defection before retaliation
+
+        Special Cases
+        -------------
+        NTitsForMTats(1,1) is equivalent to TitForTat
+        NTitsForMTats(1,2) is equivalent to TitFor2Tats
+        NTitsForMTats(2,1) is equivalent to TwoTitsForTat
+        NTitsForMTats(0,*) is equivalent to Cooperator
+        NTitsForMTats(*,0) is equivalent to Defector
+        """
+        super().__init__()
+        self.N = N
+        self.M = M
+        self.classifier['memory_depth'] = max([M, N])
+        self.retaliate_count = 0
+
+    def strategy(self, opponent: Player) -> Action:
+        # if opponent defected consecutively M times, start the retaliation
+        if not self.M or opponent.history[-self.M:].count(D) == self.M:
+            self.retaliate_count = self.N
+        if self.retaliate_count:
+            self.retaliate_count -= 1
+            return D
+        return C
+
+
+@FinalTransformer((D,), name_prefix=None)
+class Michaelos(Player):
+    """
+    Plays similar to Tit-for-Tat with two exceptions:
+    1) Defect on last turn.
+    2) After own defection and opponent's cooperation, 50 percent of the time,
+    cooperate. The other 50 percent of the time, always defect for the rest of
+    the game.
+
+    Names:
+
+    - Michaelos: [LessWrong2011]_
+    """
+
+    name = 'Michaelos'
+    classifier = {
+        'memory_depth': float('inf'),
+        'stochastic': True,
+        'makes_use_of': {'length'},
+        'long_run_time': False,
+        'inspects_source': False,
+        'manipulates_source': False,
+        'manipulates_state': False
+    }
+
+    def __init__(self):
+        super().__init__()
         self.is_defector = False
+
+    def strategy(self, opponent: Player) -> Action:
+        if not self.history:
+            return C
+        if self.is_defector:
+            return D
+        if self.history[-1] == D and opponent.history[-1] == C:
+            decision = random_choice()
+            if decision == C:
+                return C
+            else:
+                self.is_defector = True
+                return D
+
+        return opponent.history[-1]
