@@ -2,12 +2,13 @@ from collections import defaultdict
 import csv
 import logging
 from multiprocessing import Process, Queue, cpu_count
-from tempfile import NamedTemporaryFile
+from tempfile import mkstemp
 import warnings
+import os
 
 import tqdm
 
-from axelrod import on_windows, DEFAULT_TURNS
+from axelrod import DEFAULT_TURNS
 from axelrod.player import Player
 from axelrod.action import actions_to_str
 from .game import Game
@@ -23,7 +24,8 @@ class Tournament(object):
     def __init__(self, players: List[Player],
                  name: str = 'axelrod', game: Game = None, turns: int = None,
                  prob_end: float = None, repetitions: int = 10,
-                 noise: float = 0, edges: List[Tuple] = None) -> None:
+                 noise: float = 0, edges: List[Tuple] = None,
+                 match_attributes: dict = None) -> None:
         """
         Parameters
         ----------
@@ -45,6 +47,10 @@ class Tournament(object):
             The probability of a given turn ending a match
         edges : list
             A list of edges between players
+        match_attributes : dict
+            Mapping attribute names to values which should be passed to players.
+            The default is to use the correct values for turns, game and noise
+            but these can be overridden if desired.
         """
         if game is None:
             self.game = Game()
@@ -67,24 +73,26 @@ class Tournament(object):
                                               repetitions=self.repetitions,
                                               prob_end=prob_end,
                                               noise=self.noise,
-                                              edges=edges)
+                                              edges=edges,
+                                              match_attributes=match_attributes)
         self._logger = logging.getLogger(__name__)
 
+        self.use_progress_bar = True
+        self.filename = None  # type: str
+        self._temp_file_descriptor = None  # type: int
+
     def setup_output(self, filename=None, in_memory=False):
-        """Open a CSV writer for tournament output."""
+        """assign/create `filename` to `self`. If file should be deleted once
+        `play` is finished, assign a file descriptor. """
+        temp_file_descriptor = None
         if in_memory:
             self.interactions_dict = {}
-            self.writer = None
-        else:
-            if filename:
-                self.outputfile = open(filename, 'w')
-            else:
-                # Setup a temporary file
-                self.outputfile = NamedTemporaryFile(mode='w')
-                filename = self.outputfile.name
-            self.writer = csv.writer(self.outputfile, lineterminator='\n')
-            # Save filename for loading ResultSet later
-            self.filename = filename
+            filename = None
+        if not in_memory and filename is None:
+            temp_file_descriptor, filename = mkstemp()
+
+        self.filename = filename
+        self._temp_file_descriptor = temp_file_descriptor
 
     def play(self, build_results: bool = True, filename: str = None,
              processes: int = None, progress_bar: bool = True,
@@ -114,12 +122,9 @@ class Tournament(object):
         -------
         axelrod.ResultSetFromFile
         """
-        if progress_bar:
-            self.progress_bar = tqdm.tqdm(total=len(self.match_generator),
-                                          desc="Playing matches")
+        self.num_interactions = 0
 
-        if on_windows and (filename is None):  # pragma: no cover
-            in_memory = True
+        self.use_progress_bar = progress_bar
 
         self.setup_output(filename, in_memory)
 
@@ -128,27 +133,24 @@ class Tournament(object):
                 "Tournament results will not be accessible since "
                 "build_results=False and no filename was supplied.")
 
-        if (processes is None) or (on_windows):
-            self._run_serial(progress_bar=progress_bar)
+        if processes is None:
+            self._run_serial()
         else:
-            self._run_parallel(processes=processes, progress_bar=progress_bar)
-
-        if progress_bar:
-            self.progress_bar.close()
-
-        # Make sure that python has finished writing to disk
-        if not in_memory:
-            self.outputfile.flush()
+            self._run_parallel(processes=processes)
 
+        result_set = None
         if build_results:
-            return self._build_result_set(progress_bar=progress_bar,
-                                          keep_interactions=keep_interactions,
-                                          in_memory=in_memory)
-        elif not in_memory:
-            self.outputfile.close()
+            result_set = self._build_result_set(
+                keep_interactions=keep_interactions, in_memory=in_memory
+            )
 
-    def _build_result_set(self, progress_bar: bool = True,
-                          keep_interactions: bool = False,
+        if self._temp_file_descriptor is not None:
+            os.close(self._temp_file_descriptor)
+            os.remove(self.filename)
+
+        return result_set
+
+    def _build_result_set(self, keep_interactions: bool = False,
                           in_memory: bool = False):
         """
         Build the result set (used by the play method)
@@ -160,51 +162,64 @@ class Tournament(object):
         if not in_memory:
             result_set = ResultSetFromFile(
                 filename=self.filename,
-                progress_bar=progress_bar,
+                progress_bar=self.use_progress_bar,
                 num_interactions=self.num_interactions,
                 repetitions=self.repetitions,
                 players=[str(p) for p in self.players],
                 keep_interactions=keep_interactions,
                 game=self.game)
-            self.outputfile.close()
         else:
             result_set = ResultSet(
                 players=[str(p) for p in self.players],
                 interactions=self.interactions_dict,
                 repetitions=self.repetitions,
-                progress_bar=progress_bar,
+                progress_bar=self.use_progress_bar,
                 game=self.game)
         return result_set
 
-    def _run_serial(self, progress_bar: bool = False) -> bool:
-        """
-        Run all matches in serial
+    def _run_serial(self) -> bool:
+        """Run all matches in serial."""
 
-        Parameters
-        ----------
-
-        progress_bar : bool
-            Whether or not to update the tournament progress bar
-        """
         chunks = self.match_generator.build_match_chunks()
 
+        out_file, writer = self._get_file_objects()
+        progress_bar = self._get_progress_bar()
+
         for chunk in chunks:
             results = self._play_matches(chunk)
-            self._write_interactions(results)
+            self._write_interactions(results, writer=writer)
 
-            if progress_bar:
-                self.progress_bar.update(1)
+            if self.use_progress_bar:
+                progress_bar.update(1)
+
+        _close_objects(out_file, progress_bar)
 
         return True
 
-    def _write_interactions(self, results):
-        """Write the interactions to file or to a dictionary"""
-        if self.writer is not None:
-          self._write_interactions_to_file(results)
-        elif self.interactions_dict is not None:
-          self._write_interactions_to_dict(results)
+    def _get_file_objects(self):
+        """Returns the file object and writer for writing results or
+        (None, None) if self.filename is None"""
+        file_obj = None
+        writer = None
+        if self.filename is not None:
+            file_obj = open(self.filename, 'w')
+            writer = csv.writer(file_obj, lineterminator='\n')
+        return file_obj, writer
 
-    def _write_interactions_to_file(self, results):
+    def _get_progress_bar(self):
+        if self.use_progress_bar:
+            return tqdm.tqdm(total=self.match_generator.size,
+                             desc="Playing matches")
+        return None
+
+    def _write_interactions(self, results, writer=None):
+        """Write the interactions to file or to a dictionary"""
+        if writer is not None:
+            self._write_interactions_to_file(results, writer)
+        elif self.interactions_dict is not None:
+            self._write_interactions_to_dict(results)
+
+    def _write_interactions_to_file(self, results, writer):
         """Write the interactions to csv."""
         for index_pair, interactions in results.items():
             for interaction in interactions:
@@ -215,7 +230,7 @@ class Tournament(object):
                 history2 = actions_to_str([i[1] for i in interaction])
                 row.append(history1)
                 row.append(history2)
-                self.writer.writerow(row)
+                writer.writerow(row)
                 self.num_interactions += 1
 
     def _write_interactions_to_dict(self, results):
@@ -228,22 +243,20 @@ class Tournament(object):
                     self.interactions_dict[index_pair] = [interaction]
                 self.num_interactions += 1
 
-    def _run_parallel(self, processes: int=2, progress_bar: bool = False
-                      ) -> bool:
+    def _run_parallel(self, processes: int=2) -> bool:
         """
         Run all matches in parallel
 
         Parameters
         ----------
 
-        progress_bar : bool
-            Whether or not to update the tournament progress bar
+        processes : int
+            How many processes to use.
         """
         # At first sight, it might seem simpler to use the multiprocessing Pool
-        # Class rather than Processes and Queues. However, Pool can only accept
-        # target functions which can be pickled and instance methods cannot.
-        work_queue = Queue()
-        done_queue = Queue()
+        # Class rather than Processes and Queues. However, this way is faster.
+        work_queue = Queue()  # type: Queue
+        done_queue = Queue()  # type: Queue
         workers = self._n_workers(processes=processes)
 
         chunks = self.match_generator.build_match_chunks()
@@ -251,7 +264,7 @@ class Tournament(object):
             work_queue.put(chunk)
 
         self._start_workers(workers, work_queue, done_queue)
-        self._process_done_queue(workers, done_queue, progress_bar=progress_bar)
+        self._process_done_queue(workers, done_queue)
 
         return True
 
@@ -290,8 +303,7 @@ class Tournament(object):
             process.start()
         return True
 
-    def _process_done_queue(self, workers: int, done_queue: Queue,
-                            progress_bar: bool = False):
+    def _process_done_queue(self, workers: int, done_queue: Queue):
         """
         Retrieves the matches from the parallel sub-processes
 
@@ -301,20 +313,22 @@ class Tournament(object):
             The number of sub-processes in existence
         done_queue : multiprocessing.Queue
             A queue containing the output dictionaries from each round robin
-        progress_bar : bool
-            Whether or not to update the tournament progress bar
         """
+        out_file, writer = self._get_file_objects()
+        progress_bar = self._get_progress_bar()
+
         stops = 0
         while stops < workers:
             results = done_queue.get()
-
             if results == 'STOP':
                 stops += 1
             else:
-                self._write_interactions(results)
+                self._write_interactions(results, writer)
 
-                if progress_bar:
-                    self.progress_bar.update(1)
+                if self.use_progress_bar:
+                    progress_bar.update(1)
+
+        _close_objects(out_file, progress_bar)
         return True
 
     def _worker(self, work_queue: Queue, done_queue: Queue):
@@ -361,3 +375,10 @@ class Tournament(object):
             match.play()
             interactions[index_pair].append(match.result)
         return interactions
+
+
+def _close_objects(*objs):
+    """If the objects have a `close` method, closes them."""
+    for obj in objs:
+        if hasattr(obj, 'close'):
+            obj.close()
